from setuptools import setup, find_packages

setup(
    name="orm-sdk",
    #same name should be given PyPi account
    version="1.0.1",
    description="A simple ORM SDK in Python",  
    author="Megha Salimath",         
    
    # Minimal Python version
    python_requires=">=3.10",
    
    # Runtime dependencies
    install_requires=[
        "psycopg[binary]>=3.1.18",  
        "dotenv"
    ],
    # If you want to include non-python files (README, LICENSE, etc.)
    include_package_data=True,
    
)